IStablecoinDEXInstance

Struct IStablecoinDEXInstance 

pub struct IStablecoinDEXInstance<P, N = Ethereum> {
    address: Address,
    provider: P,
    _network: PhantomData<N>,
}
A IStablecoinDEX instance.

Contains type-safe methods for interacting with an on-chain instance of the IStablecoinDEX contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Fields

address: Addressprovider: P_network: PhantomData<N>

Implementations



impl<P, N> IStablecoinDEXInstance<P, N>
where P: Provider<N>, N: Network,

Instantiation and getters/setters.

pub const fn new( address: Address, __provider: P, ) -> IStablecoinDEXInstance<P, N>

Creates a new wrapper around an on-chain IStablecoinDEX contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> IStablecoinDEXInstance<P, N>

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.



impl<P, N> IStablecoinDEXInstance<&P, N>
where P: Clone,

pub fn with_cloned_provider(self) -> IStablecoinDEXInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.



impl<P, N> IStablecoinDEXInstance<P, N>
where P: Provider<N>, N: Network,

Function calls.

pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>
where C: SolCall,

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn createPair( &self, base: Address, ) -> CallBuilder<&P, PhantomData<createPairCall>, N>

Creates a new call builder for the [createPair] function.

pub fn place( &self, token: Address, amount: u128, isBid: bool, tick: i16, ) -> CallBuilder<&P, PhantomData<placeCall>, N>

Creates a new call builder for the [place] function.

pub fn placeFlip( &self, token: Address, amount: u128, isBid: bool, tick: i16, flipTick: i16, ) -> CallBuilder<&P, PhantomData<placeFlipCall>, N>

Creates a new call builder for the [placeFlip] function.

pub fn cancel( &self, orderId: u128, ) -> CallBuilder<&P, PhantomData<cancelCall>, N>

Creates a new call builder for the [cancel] function.

pub fn cancelStaleOrder( &self, orderId: u128, ) -> CallBuilder<&P, PhantomData<cancelStaleOrderCall>, N>

Creates a new call builder for the [cancelStaleOrder] function.

pub fn swapExactAmountIn( &self, tokenIn: Address, tokenOut: Address, amountIn: u128, minAmountOut: u128, ) -> CallBuilder<&P, PhantomData<swapExactAmountInCall>, N>

Creates a new call builder for the [swapExactAmountIn] function.

pub fn swapExactAmountOut( &self, tokenIn: Address, tokenOut: Address, amountOut: u128, maxAmountIn: u128, ) -> CallBuilder<&P, PhantomData<swapExactAmountOutCall>, N>

Creates a new call builder for the [swapExactAmountOut] function.

pub fn quoteSwapExactAmountIn( &self, tokenIn: Address, tokenOut: Address, amountIn: u128, ) -> CallBuilder<&P, PhantomData<quoteSwapExactAmountInCall>, N>

Creates a new call builder for the [quoteSwapExactAmountIn] function.

pub fn quoteSwapExactAmountOut( &self, tokenIn: Address, tokenOut: Address, amountOut: u128, ) -> CallBuilder<&P, PhantomData<quoteSwapExactAmountOutCall>, N>

Creates a new call builder for the [quoteSwapExactAmountOut] function.

pub fn balanceOf( &self, user: Address, token: Address, ) -> CallBuilder<&P, PhantomData<balanceOfCall>, N>

Creates a new call builder for the [balanceOf] function.

pub fn withdraw( &self, token: Address, amount: u128, ) -> CallBuilder<&P, PhantomData<withdrawCall>, N>

Creates a new call builder for the [withdraw] function.

pub fn getOrder( &self, orderId: u128, ) -> CallBuilder<&P, PhantomData<getOrderCall>, N>

Creates a new call builder for the [getOrder] function.

pub fn getTickLevel( &self, base: Address, tick: i16, isBid: bool, ) -> CallBuilder<&P, PhantomData<getTickLevelCall>, N>

Creates a new call builder for the [getTickLevel] function.

pub fn pairKey( &self, tokenA: Address, tokenB: Address, ) -> CallBuilder<&P, PhantomData<pairKeyCall>, N>

Creates a new call builder for the [pairKey] function.

pub fn nextOrderId(&self) -> CallBuilder<&P, PhantomData<nextOrderIdCall>, N>

Creates a new call builder for the [nextOrderId] function.

pub fn books( &self, pairKey: FixedBytes<32>, ) -> CallBuilder<&P, PhantomData<booksCall>, N>

Creates a new call builder for the [books] function.

pub fn MIN_TICK(&self) -> CallBuilder<&P, PhantomData<MIN_TICKCall>, N>

Creates a new call builder for the [MIN_TICK] function.

pub fn MAX_TICK(&self) -> CallBuilder<&P, PhantomData<MAX_TICKCall>, N>

Creates a new call builder for the [MAX_TICK] function.

pub fn TICK_SPACING(&self) -> CallBuilder<&P, PhantomData<TICK_SPACINGCall>, N>

Creates a new call builder for the [TICK_SPACING] function.

pub fn PRICE_SCALE(&self) -> CallBuilder<&P, PhantomData<PRICE_SCALECall>, N>

Creates a new call builder for the [PRICE_SCALE] function.

pub fn MIN_ORDER_AMOUNT( &self, ) -> CallBuilder<&P, PhantomData<MIN_ORDER_AMOUNTCall>, N>

Creates a new call builder for the [MIN_ORDER_AMOUNT] function.

pub fn MIN_PRICE(&self) -> CallBuilder<&P, PhantomData<MIN_PRICECall>, N>

Creates a new call builder for the [MIN_PRICE] function.

pub fn MAX_PRICE(&self) -> CallBuilder<&P, PhantomData<MAX_PRICECall>, N>

Creates a new call builder for the [MAX_PRICE] function.

pub fn tickToPrice( &self, tick: i16, ) -> CallBuilder<&P, PhantomData<tickToPriceCall>, N>

Creates a new call builder for the [tickToPrice] function.

pub fn priceToTick( &self, price: u32, ) -> CallBuilder<&P, PhantomData<priceToTickCall>, N>

Creates a new call builder for the [priceToTick] function.



impl<P, N> IStablecoinDEXInstance<P, N>
where P: Provider<N>, N: Network,

Event filters.

pub fn event_filter<E>(&self) -> Event<&P, E, N>
where E: SolEvent,

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn PairCreated_filter(&self) -> Event<&P, PairCreated, N>

Creates a new event filter for the PairCreated event.

pub fn OrderPlaced_filter(&self) -> Event<&P, OrderPlaced, N>

Creates a new event filter for the OrderPlaced event.

pub fn OrderFilled_filter(&self) -> Event<&P, OrderFilled, N>

Creates a new event filter for the OrderFilled event.

pub fn OrderFlipped_filter(&self) -> Event<&P, OrderFlipped, N>

Creates a new event filter for the OrderFlipped event.

pub fn FlipFailed_filter(&self) -> Event<&P, FlipFailed, N>

Creates a new event filter for the FlipFailed event.

pub fn OrderCancelled_filter(&self) -> Event<&P, OrderCancelled, N>

Creates a new event filter for the OrderCancelled event.